automaticSessionPolicy property
Controls whether an automatically created session spans the process or rolls at configured adaptive boundaries.
Implementation
final ArgosAutomaticSessionPolicy automaticSessionPolicy;
Controls whether an automatically created session spans the process or rolls at configured adaptive boundaries.
final ArgosAutomaticSessionPolicy automaticSessionPolicy;