ArgosAutomaticSessionPolicy class

Immutable boundary policy for sessions created by automatic mode.

Constructors

ArgosAutomaticSessionPolicy.adaptive({Duration? backgroundTimeout = const Duration(minutes: 2), Duration? maxDuration = const Duration(minutes: 30), ArgosSessionContext contextProvider()?})
ArgosAutomaticSessionPolicy.process()
const

Properties

backgroundTimeout Duration?
final
contextProvider ArgosSessionContext Function()?
final
hashCode int
The hash code for this object.
no setterinherited
maxDuration Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strategy ArgosAutomaticSessionStrategy
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited