ArgosAutomaticSessionStrategy enum

How automatic mode decides the boundary of a diagnostic session.

Inheritance
Available extensions

Values

process → const ArgosAutomaticSessionStrategy

Preserve one session for the lifetime of the initialized process.

adaptive → const ArgosAutomaticSessionStrategy

Roll sessions at configured lifecycle, duration, or context boundaries.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ArgosAutomaticSessionStrategy>
A constant List of the values in this enum, in order of their declaration.