ArgosSessionContext class

Host-defined context used only by adaptive automatic sessions.

fingerprint is compared in memory and is never persisted automatically. Only the explicitly supplied attributes are copied into a session.

Constructors

ArgosSessionContext({required String fingerprint, Map<String, String> attributes = const <String, String>{}})

Properties

attributes Map<String, String>
final
fingerprint String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited