ArgosHttpInfo class

Inheritance

Constructors

ArgosHttpInfo(Uri? uri, String method)

Properties

error String?
getter/setter pair
eventMetadata ArgosEventMetadata?
Session identity assigned only after the event passes dispatch gating.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
method String
final
recorded bool
getter/setter pair
recordTime int
finalinherited
request HttpRequest
getter/setter pair
response HttpResponse
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp int
final
type ArgosCapability?
getter/setter pairoverride
uri Uri?
final

Methods

getValue() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited