ArgosBaseModel class

Implementers

Constructors

ArgosBaseModel()

Properties

eventMetadata ↔ ArgosEventMetadata?
Session identity assigned only after the event passes dispatch gating.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
recordTime → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ArgosCapability?
getter/setter pair

Methods

getValue() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited