ArgosRecordEntry class

A single record, rendered on its own row.

Inheritance

Constructors

ArgosRecordEntry(ArgosPacketRecord record)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
record → ArgosPacketRecord
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited