ArgosTuningTarget class

Immutable view of one currently mounted tuning target.

Annotations

Constructors

ArgosTuningTarget({required String id, required String label, required List<ArgosTuningProperty> properties, required ArgosTuningValues values, Rect? bounds})
const

Properties

bounds → Rect?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
label → String
final
properties → List<ArgosTuningProperty>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → ArgosTuningValues
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited