ArgosHttpMonitor class

Implemented types

Properties

config ArgosConfig?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
proxyProvider String? Function()?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispatchForTesting(ArgosHttpInfo info) Future<void>
init({ArgosConfig? config}) ArgosHttpMonitor
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReport(ArgosBaseModel model) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ArgosHttpMonitor
no setter