ArgosManager class

Properties

activeSession ArgosDiagnosticSession?
no setter
captureEnabled bool
Compatibility view over the diagnostic-session state machine.
getter/setter pair
config ArgosConfig?
getter/setter pair
currentRoute String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
listener ↔ dynamic Function(ArgosBaseModel?)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionState ArgosSessionState
no setter

Methods

clear() Future<void>
dispatch(ArgosBaseModel model, {ArgosPacketRecord? record}) Future<void>
The single admission and metadata-allocation point for persistable events. Rejected events return immediately without notifying, writing, or consuming a sequence number.
flush() Future<void>
getSessionRecords(String sessionId) Future<List<ArgosPacketRecord>>
getSessions() Future<List<ArgosDiagnosticSession>>
handleAppLifecycleStateForTesting(AppLifecycleState state) → void
init({ArgosConfig? config, dynamic listener(ArgosBaseModel?)?}) ArgosManager
initializeMonitors() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseSession() → void
resetForTesting() → void
resumeSession() → void
setNowForTesting(DateTime now()?) → void
startSession({String? label, String? note, Map<String, String> attributes = const <String, String>{}}) ArgosDiagnosticSession
stopSession() Future<ArgosDiagnosticSession?>
toString() String
A string representation of this object.
inherited
updateProxyProvider(String? provider()) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ArgosManager
no setter