ArgosManager class

Properties

captureEnabled bool
getter/setter pair
config ArgosConfig?
getter/setter pair
currentRoute String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
listener ↔ dynamic Function(ArgosBaseModel?)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispatch(ArgosBaseModel model, {ArgosPacketRecord? record}) → void
Shared dispatch path for monitor events: always notifies listener, and persists record to ArgosPacketStorage when storage is enabled.
init({ArgosConfig? config, dynamic listener(ArgosBaseModel?)?}) ArgosManager
initializeMonitors() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateProxyProvider(String? provider()) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ArgosManager
no setter