ArgosNativeCapture class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disable(
) → Future< void> -
enable(
) → Future< void> - Enables native packet capture on iOS and Android. Idempotent — safe to call multiple times.
-
handleEventForTesting(
dynamic event) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ArgosNativeCapture
-
no setter