peakRss property
int
get
peakRss
Highest sample in the run. Surfaced in the collapsed state on purpose: an average or a last-value would hide a spike, which is the one thing you open a memory timeline to find.
Implementation
int get peakRss => series.reduce((a, b) => a > b ? a : b);