ArgosDoubleTuningProperty class

A bounded numeric tuning property rendered as a slider.

Inheritance

Constructors

ArgosDoubleTuningProperty({required String id, required String label, required double initialValue, required double min, required double max, int? divisions, int decimalPlaces = 1})
const

Properties

decimalPlaces int
final
divisions int?
final
hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier used by ArgosTuningValues.
finalinherited
initialValue double
Source-controlled value used before an override exists and after reset.
final
label String
Human-readable label shown in the on-device editor.
finalinherited
max double
final
min double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(Object value) bool
override
format(double value) String
normalize(Object value) double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited