ArgosDoubleTuningProperty class
A bounded numeric tuning property rendered as a slider.
- Inheritance
-
- Object
- ArgosTuningProperty
- ArgosDoubleTuningProperty
Constructors
Properties
- decimalPlaces → int
-
final
- divisions → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable identifier used by ArgosTuningValues.
finalinherited
- initialValue → double
-
Source-controlled value used before an override exists and after reset.
final
- label → String
-
Human-readable label shown in the on-device editor.
finalinherited
- max → double
-
final
- min → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited