ArgosTuningProperty class abstract

Describes one value that an ArgosTunable exposes to the inspector.

Implementers

Constructors

ArgosTuningProperty({required String id, required String label})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier used by ArgosTuningValues.
final
initialValue Object
Source-controlled value used before an override exists and after reset.
no setter
label String
Human-readable label shown in the on-device editor.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(Object value) bool
normalize(Object value) Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited