ArgosTuningValues class
Immutable typed values passed to an ArgosTunableBuilder.
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
colorValue(
String propertyId) → Color -
contains(
String propertyId) → bool -
doubleValue(
String propertyId) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> -
toString(
) → String -
A string representation of this object.
inherited
-
value(
String propertyId) → Object
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited